<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_about_one extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-about-onee';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home About: 01', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_title_about', [
            'label' => esc_html__( 'Section Title', 'kewi-extra' ),
        ] );


        $this->add_control( 'subtitle', [
            'label'       => __( 'Sub Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'default'     => __( 'About Us', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section subtitle here.", 'kewi-extra' ),
        ] );

        $this->add_control( 'title', [
            'label'       => __( 'Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'kewi-extra' ),

        ] );


        $this->end_controls_section();


        $this->start_controls_section( 'section_content_about_inner', [
            'label' => esc_html__( 'About Content', 'kewi-extra' ),
        ] ); 


        $this->add_control( 'about_feature_image', [
            'label'   => __( 'Choose Image', 'kewi-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );

        $this->add_control( 'description', [
            'label'       => __( 'Description', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Our Sustainable Construction Advisors provide sustainable construction expertise', 'kewi-extra' ),
            'label_block' => true,
        ] );


        $this->add_control( 'btn_text', [
            'label'       => __( 'Button Label', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type your button label here', 'kewi-extra' ),
            'default'     => __( 'Get in touch', 'kewi-extra' ),
        ] );

        $this->add_control( 'btn_link', [
            'label'       => __( 'Button Link', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::URL,
            'placeholder' => __( 'https://your-link.com', 'kewi-extra' ),
            'default'     => [
                'url' => '#',
            ],
        ] );



        $this->end_controls_section();

        $this->start_controls_section( 'section_content_about_featurelist', [
            'label' => esc_html__( 'About feature List', 'kewi-extra' ),
        ] ); 


        $this->add_control( 'feature-sec-title', [
            'label'       => __( 'Feature Section Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'FEATURED ON', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type feature section title here.", 'kewi-extra' ),

        ] );

        $this->add_control( 'featureItems', [
            'label'       => esc_html__( 'About features items', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'feature-title'        => esc_html__( 'Design Agency Award 2023', 'kewi-extra' ),
                ]
            ],

            'fields'      => [
                [
                    'name'        => 'feature-title',
                    'label'       => esc_html__( 'Title', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'description' => esc_html__( 'Enter Title', 'kewi-extra' )
                ],
                

                [
                    'name'        => 'feature-link',
                    'type'        => \Elementor\Controls_Manager::URL,
                    'placeholder' => __( 'https://your-link.com', 'kewi-extra' ),
                    'default'     => [
                        'url' => '#',
                    ],
                ],




            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();


        // ===================== Title ======================//

        $this->start_controls_section( 'title_style', [
            'label' => __( 'Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '
                {{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading,
                {{WRAPPER}} .__title
            ',
        ] );


        $this->add_control( 'title_color', [
            'label'     => __( 'Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Title Style


        // ===================== Subtitle Style ========================//
        $this->start_controls_section( 'sub_title_style', [
            'label' => __( 'Sub Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_sub_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading',
        ] );

        $this->add_control( 'sub_title_color', [
            'label'     => __( 'Sub Title Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading' => 'color: {{VALUE}}',
            ],

        ] );

        $this->end_controls_section(); //End Subtitle Style

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $featureItems = $settings['featureItems'];

        extract($settings); 


		
		?>


        <!-- about-area -->
        <section class="about-area pt-120 pb-120 theme-home-about-one">
            <div class="container">
                <div class="row">
                    <div class="col-lg-12">
                        <div class="section-title mb-80">
                            <span class="sub-title"><?php echo $settings['subtitle']; ?></span>
                            <h2 class="title"><?php echo wp_kses_post( $settings['title'] ); ?></h2>
                        </div>
                    </div>
                </div>
                <div class="row align-items-center justify-content-center">
                    <div class="col-lg-4 col-md-8">
                        <div class="about-img">
                            <img src="<?php echo esc_url( $settings['about_feature_image']['url'] ); ?>" alt="img">
                        </div>
                    </div>
                    <div class="col-lg-8">
                        <div class="about-content">
                            <div class="left-side-content">
                                <p><?php echo $settings['description']; ?></p>
                                <a href="<?php echo esc_url( $settings['btn_link']['url'] ) ?>" class="btn">
                                    <span><?php echo $settings['btn_text'] ?></span>
                                </a>
                            </div>
                            <div class="right-side-content">
                                <span><?php echo wp_kses_post( $settings['feature-sec-title'] ); ?></span>
                                <ul class="list-wrap">

                                    <?php
                                        foreach ( $featureItems as $item ):
                                    ?>

                                    <li><a href="<?php echo esc_url( $item['feature-link']['url'] ) ?>"><?php echo esc_html( $item['feature-title'] ); ?></a></li>

                                    <?php endforeach; ?>  

                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
        <!-- about-area-end -->


	

	<?php 


	}
				

}

