<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_animated_text_two extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-home-animated-two';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Animated Text: 02', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_text_list_mtwoo', [
            'label' => esc_html__( 'Text Items', 'kewi-extra' ),
        ] ); 


        $this->add_control( 'textItems', [
            'label'       => esc_html__( 'Add Animated Text Item', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'text-title'        => esc_html__( 'Ready To Work Together', 'kewi-extra' ),
                ]
            ],

            'fields'      => [
                [
                    'name'        => 'text-title',
                    'label'       => esc_html__( 'Text Title', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'description' => esc_html__( 'Enter Title', 'kewi-extra' )
                ],

                [
                    'name'        => 'text-link',
                    'label'       => esc_html__( 'Animated Text Link', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::URL,
                    'placeholder' => __( 'https://your-link.com', 'kewi-extra' ),
                    'default'     => [
                        'url' => '#',
                    ],
                ],
            


            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $textItems = $settings['textItems'];

        extract($settings); 


		
		?>


		<!-- marquee-area -->
            <div class="marquee-area-two">
                <div class="marquee-wrap-two">

                    <div class="marquee-box">

                    <?php
                        foreach ( $textItems as $item ):
                    ?>

                    <a href="<?php echo esc_url( $item['text-link']['url'] ) ?>" data-hover="<?php echo esc_html( $item['text-title'] ); ?>"><?php echo esc_html( $item['text-title'] ); ?></a>

                    <?php endforeach; ?>  

                	</div>


                    <div class="marquee-box">

                    <?php
                        foreach ( $textItems as $item ):
                    ?>

                    <a href="<?php echo esc_url( $item['text-link']['url'] ) ?>" data-hover="<?php echo esc_html( $item['text-title'] ); ?>"><?php echo esc_html( $item['text-title'] ); ?></a>
                    
                    <?php endforeach; ?> 
                    
               		</div>


                </div>
            </div>
            <!-- marquee-area-end -->



	<?php 


	}
				

}

