<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_counter_one extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-counter-onee';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Counter: 01', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_title_counter', [
            'label' => esc_html__( 'Section Title and Button', 'kewi-extra' ),
        ] );


        $this->add_control( 'subtitle', [
            'label'       => __( 'Sub Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'default'     => __( 'About Us', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section subtitle here.", 'kewi-extra' ),
        ] );

        $this->add_control( 'title', [
            'label'       => __( 'Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'kewi-extra' ),

        ] );

        $this->add_control( 'btn_text', [
            'label'       => __( 'Button Label', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type your button label here', 'kewi-extra' ),
            'default'     => __( 'View More', 'kewi-extra' ),
        ] );

        $this->add_control( 'btn_link', [
            'label'       => __( 'Button Link', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::URL,
            'placeholder' => __( 'https://your-link.com', 'kewi-extra' ),
            'default'     => [
                'url' => '#',
            ],
        ] );


        $this->end_controls_section();


        $this->start_controls_section( 'section_content_counter_itemlist', [
            'label' => esc_html__( 'Counter Item List', 'kewi-extra' ),
        ] ); 

        $this->add_control( 'counterItems', [
            'label'       => esc_html__( 'Counter Single Item', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'counter-title'        => esc_html__( 'Realized Projects', 'kewi-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'counter-title',
                    'label'       => esc_html__( 'Title', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Realized Projects', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter Title', 'kewi-extra' )
                ],

                [
                    'name'        => 'progress-number',
                    'label'       => esc_html__( 'Set Progress Bar Parcentage in Number', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::NUMBER,
                    'min'         => 1,
                    'max'         => 100,
                    'step'        => 5,
                    'default'     => 75,
                ],

                [
                    'name'        => 'count-number',
                    'label'       => esc_html__( 'Set Counter Number', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::NUMBER,
                    'min'         => 1,
                    'max'         => 100,
                    'step'        => 5,
                    'default'     => 69,
                ],



            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();


        // ===================== Title ======================//

        $this->start_controls_section( 'title_style', [
            'label' => __( 'Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '
                {{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading,
                {{WRAPPER}} .__title
            ',
        ] );


        $this->add_control( 'title_color', [
            'label'     => __( 'Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Title Style


        // ===================== Subtitle Style ========================//
        $this->start_controls_section( 'sub_title_style', [
            'label' => __( 'Sub Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_sub_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading',
        ] );

        $this->add_control( 'sub_title_color', [
            'label'     => __( 'Sub Title Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading' => 'color: {{VALUE}}',
            ],

        ] );

        $this->end_controls_section(); //End Subtitle Style

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $counterItems = $settings['counterItems'];

        extract($settings); 


		
		?>


<!--     <script type="text/javascript">
    
        jQuery(document).ready(function ($) {
            
           jQuery('.odometer').appear(function (e) {
                var odo = $(".odometer");
                odo.each(function () {
                    var countNumber = $(this).attr("data-count");
                    $(this).html(countNumber);
                });
            });

        });

    </script>  -->




            <!-- counter-area -->
            <section class="counter-area pt-120 pb-120">
                <div class="container">
                    <div class="row">
                        <div class="col-xl-7 col-lg-6">
                            <div class="counter-content">
                                <div class="section-title mb-200">
                                    <span class="sub-title"><?php echo $settings['subtitle']; ?></span>
                                    <h2 class="title"><?php echo wp_kses_post( $settings['title'] ); ?></h2>
                                </div>
                                <div class="view-more-btn">
                                    <a href="<?php echo esc_url( $settings['btn_link']['url'] ) ?>" class="btn"><?php echo esc_html( $settings['btn_text'] ); ?></a>
                                </div>
                            </div>
                        </div>
                        <div class="col-xl-5 col-lg-6">
                            <div class="counter-progress-wrap">
                                <div class="progress-wrap">


                                    <?php
                                        foreach ( $counterItems as $item ):
                                    ?>

                                    <div class="progress" role="progressbar" aria-label="Example with label" aria-valuenow="<?php echo $item['progress-number']; ?>" aria-valuemin="0" aria-valuemax="100">
                                        <div class="progress-bar" style="height: <?php echo $item['progress-number']; ?>%">
                                            <span><?php echo wp_kses_post( $item['counter-title'] ); ?></span>
                                        </div>
                                    </div>

                                    <?php endforeach; ?> 

                                </div>

                                <div class="counter-wrap">
                                    <ul class="list-wrap">

                                        <li>
                                            <h2 class="count"><span id="odometer" class="odometer" data-count="69"></span>%</h2>
                                        </li>
                                        <li>
                                            <h2 class="count"><span class="odometer" data-count="41"></span>%</h2>
                                        </li>
                                        <li>
                                            <h2 class="count"><span class="odometer" data-count="35"></span>+</h2>
                                        </li>
                                        <li>
                                            <h2 class="count"><span class="odometer" data-count="48"></span>+</h2>
                                        </li>



                                    </ul>
                                </div>

                            </div>
                        </div>
                    </div>
                </div>
            </section>
            <!-- counter-area-end -->


	<?php 


	}
				

}

