<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_counter_two extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-counter-two';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Counter: 02', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {



        $this->start_controls_section( 'section_content_counter_itemlisttwo', [
            'label' => esc_html__( 'Counter Item List', 'kewi-extra' ),
        ] ); 

        $this->add_control( 'counterItems', [
            'label'       => esc_html__( 'Counter Single Item', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'counter-title'        => esc_html__( 'Realized Projects', 'kewi-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'counter-title',
                    'label'       => esc_html__( 'Title', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Realized Projects', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter Title', 'kewi-extra' )
                ],

                [
                    'name'        => 'counter-sub-text',
                    'label'       => esc_html__( 'Sub Title', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Realized Projects', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter Title', 'kewi-extra' )
                ],

                
                [
                    'name'        => 'progress-number',
                    'label'       => esc_html__( 'Set Progress Bar Parcentage in Number', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::NUMBER,
                    'min'         => 1,
                    'max'         => 100,
                    'step'        => 5,
                    'default'     => 75,
                ],

                [
                    'name'        => 'count-number',
                    'label'       => esc_html__( 'Set Counter Number', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::NUMBER,
                    'min'         => 1,
                    'max'         => 100,
                    'step'        => 5,
                    'default'     => 69,
                ],

                [
                    'name'        => 'counter-btn-link',
                    'label'       => esc_html__( 'Counter Bottom Button Link', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::URL,
                    'placeholder' => __( 'https://your-link.com', 'kewi-extra' ),
                    'default'     => [
                        'url' => '#',
                    ],
                ],



            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();


        // ===================== Title ======================//

        $this->start_controls_section( 'title_style', [
            'label' => __( 'Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '
                {{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading,
                {{WRAPPER}} .__title
            ',
        ] );


        $this->add_control( 'title_color', [
            'label'     => __( 'Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Title Style


        // ===================== Subtitle Style ========================//
        $this->start_controls_section( 'sub_title_style', [
            'label' => __( 'Sub Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_sub_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading',
        ] );

        $this->add_control( 'sub_title_color', [
            'label'     => __( 'Sub Title Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading' => 'color: {{VALUE}}',
            ],

        ] );

        $this->end_controls_section(); //End Subtitle Style

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $counterItems = $settings['counterItems'];

        extract($settings); 


		
		?>


        <!-- counter-area -->
        <section class="counter-area-two">
            <div class="container">
                <div class="counter-item-wrap">
                    <div class="row justify-content-center">

                        <?php
                            foreach ( $counterItems as $item ):
                        ?>

                        <div class="col-xl-3 col-lg-4 col-md-6">
                            <div class="counter-item">
                                <div class="counter-top">
                                    <h2 class="count"><span class="odometer" data-count="68"></span>%</h2>
                                    <p><?php echo wp_kses_post( $item['counter-title'] ); ?></p>
                                </div>
                                <div class="progress" role="progressbar" aria-label="Example with label" aria-valuenow="<?php echo $item['progress-number']; ?>" aria-valuemin="0" aria-valuemax="100">
                                    <div class="progress-bar" style="width: <?php echo $item['progress-number']; ?>%"></div>
                                </div>
                                <p><?php echo wp_kses_post( $item['counter-sub-text'] ); ?></p>
                                <div class="icon">
                                    <a href="<?php echo esc_url( $item['counter-btn-link']['url'] ) ?>"><i class="flaticon-plus"></i></a>
                                </div>
                            </div>
                        </div>

                        <?php endforeach; ?> 


                    </div>
                </div>
            </div>
        </section>
        <!-- counter-area-end -->



	<?php 


	}
				

}

