<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_pricing extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-home-pricing';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Pricing: 01', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_pricing', [
            'label' => esc_html__( 'Section Title', 'kewi-extra' ),
        ] );


        $this->add_control( 'subtitle', [
            'label'       => __( 'Sub Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'default'     => __( 'About Us', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section subtitle here.", 'kewi-extra' ),
        ] );

        $this->add_control( 'title', [
            'label'       => __( 'Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'kewi-extra' ),

        ] );

        $this->add_control( 'pricing_bg_color', [
            'label'     => __( 'Set Section Background Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'default'   => __( '#f8f8f8', 'kewi-extra' ),
            'selectors' => [
                '{{WRAPPER}} .pricing-area' => 'background: {{VALUE}}',
            ],

        ] );

        $this->add_control(
            'enable_titlebar',
            [
                'label' => esc_html__( 'Show title bar', 'kewi-extra' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'kewi-extra' ),
                'label_off' => esc_html__( 'Hide', 'kewi-extra' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'enable_border',
            [
                'label' => esc_html__( 'Show Bordered Style', 'kewi-extra' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'kewi-extra' ),
                'label_off' => esc_html__( 'Hide', 'kewi-extra' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );


        $this->end_controls_section();


        $this->start_controls_section( 'section_content_pricing_list', [
            'label' => esc_html__( 'Pricing Items', 'kewi-extra' ),
        ] ); 

        $this->add_control( 'pricingItems', [
            'label'       => esc_html__( 'Pricing Single Item', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'timeline-year'        => esc_html__( '2014', 'kewi-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'pricing-title',
                    'label'       => esc_html__( 'Set Pricing', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( '$99.99', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter Pricing', 'kewi-extra' )
                ],

                [
                    'name'        => 'plan-title',
                    'label'       => esc_html__( 'Plan Name', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Agency Plan', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter Pricing Plan', 'kewi-extra' )
                ],

                [
                    'name'        => 'pricing-sub-title',
                    'label'       => esc_html__( 'Sub Title', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Contracts define three different scopes of services', 'kewi-extra' ),
                    'label_block' => true,
                    'description' => esc_html__( 'Enter Sub Title', 'kewi-extra' )
                ],

                [
                    'name'        => 'pricing-content',
                    'label'       => esc_html__( 'Pricing Features', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::WYSIWYG,
                    'default'     => __( 'Design Development', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter pricing features list', 'kewi-extra' )
                ],

                [
                    'name'        => 'btn-link',
                    'label'       => esc_html__( 'Pricing Button Link', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::URL,
                    'placeholder' => __( 'https://your-link.com', 'kewi-extra' ),
                    'default'     => [
                        'url' => '#',
                    ],
                ],

                [
                    'name'        => 'btn-text',
                    'label'       => esc_html__( 'Pricing Button Text', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Purchase Now', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter Button Text', 'kewi-extra' )
                ],

                [
                    'name'        => 'pricing-column',
                    'label'     =>esc_html__( 'Select Grid Column', 'sasspark-extra' ),
                    'type'      => \Elementor\Controls_Manager::SELECT,
                    'default'   => 'col-lg-4 col-md-6',
                    'options'   => [
                        'col-lg-6 col-md-6'    =>esc_html__( '2 Columns', 'sasspark-extra' ),
                        'col-lg-4 col-md-6'    =>esc_html__( '3 Columns', 'sasspark-extra' ),
                        'col-lg-3 col-md-6'    =>esc_html__( '4 Columns', 'sasspark-extra' ),
                    ],
                ],




            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();


        // ===================== Title ======================//

        $this->start_controls_section( 'title_style', [
            'label' => __( 'Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '
                {{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading,
                {{WRAPPER}} .__title
            ',
        ] );


        $this->add_control( 'title_color', [
            'label'     => __( 'Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Title Style


        // ===================== Subtitle Style ========================//
        $this->start_controls_section( 'sub_title_style', [
            'label' => __( 'Sub Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_sub_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading',
        ] );

        $this->add_control( 'sub_title_color', [
            'label'     => __( 'Sub Title Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading' => 'color: {{VALUE}}',
            ],

        ] );

        $this->end_controls_section(); //End Subtitle Style

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $pricingItems = $settings['pricingItems'];

        $enable_border = $settings['enable_border'];
        $enable_titlebar = $settings['enable_titlebar'];

        extract($settings); 


		
		?>


            <!-- pricing-area -->
            <section class="pricing-area">
                <div class="container">

                    <?php if($enable_titlebar == true) :?>
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="section-title mb-80">
                                <span class="sub-title"><?php echo $settings['subtitle']; ?></span>
                                <h2 class="title"><?php echo wp_kses_post( $settings['title'] ); ?></h2>
                            </div>
                        </div>
                    </div>
                    <?php endif; ?>

                    <div class="pricing-item-wrap <?php if( $enable_border == "yes" ) { echo "bordered-pricing"; } else { echo "no-bordered-pricing"; } ?>">
                        <div class="row justify-content-center">


                            <?php
                                foreach ( $pricingItems as $item ):
                            ?>

                            <div class="<?php echo esc_attr($item['pricing-column']);?>">
                                <div class="pricing-box">
                                    <div class="pricing-price">
                                        <h2 class="price"><?php echo wp_kses_post( $item['pricing-title'] ); ?></h2>
                                    </div>
                                    <div class="pricing-plan">
                                        <h5 class="title"><?php echo wp_kses_post( $item['plan-title'] ); ?></h5>
                                        <p><?php echo wp_kses_post( $item['pricing-sub-title'] ); ?></p>
                                    </div>
                                    <div class="pricing-list">


                                        <?php echo $item['pricing-content']; ?>


                                    </div>
                                    <div class="pricing-btn">
                                        <a href="<?php echo esc_url( $item['btn-link']['url'] ) ?>" class="btn"><span><?php echo $item['btn-text'] ?></span></a>
                                    </div>
                                </div>
                            </div>

                             <?php endforeach; ?> 




                        </div>
                    </div>
                </div>
            </section>
            <!-- pricing-area-end -->



	<?php 


	}
				

}

