<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_projects_one extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-projects-onee';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Custom Projects: 01', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_title_services', [
            'label' => esc_html__( 'Section Title', 'kewi-extra' ),
        ] );


        $this->add_control( 'subtitle', [
            'label'       => __( 'Sub Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'default'     => __( 'Projects', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section subtitle here.", 'kewi-extra' ),
        ] );

        $this->add_control( 'title', [
            'label'       => __( 'Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'kewi-extra' ),

        ] );

        $this->add_control( 'project_bg_color', [
            'label'     => __( 'Set Section Background Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'default'   => __( '#222222', 'kewi-extra' ),
            'selectors' => [
                '{{WRAPPER}} .theme-cutsom-project-wrapper' => 'background: {{VALUE}}',
            ],

        ] );


        $this->add_control(
            'project_1',
            [
                'label' => esc_html__('Project Slide Image 01','restlycore'),
                'type'=> \Elementor\Controls_Manager::MEDIA,
                'default' => [
                  'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'label_block' => true,
            ]
        );

        $this->add_control(
            'project_2',
            [
                'label' => esc_html__('Project Slide Image 02','restlycore'),
                'type'=> \Elementor\Controls_Manager::MEDIA,
                'default' => [
                  'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'label_block' => true,
            ]
        );

        $this->add_control(
            'project_3',
            [
                'label' => esc_html__('Project Slide Image 03','restlycore'),
                'type'=> \Elementor\Controls_Manager::MEDIA,
                'default' => [
                  'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'label_block' => true,
            ]
        );



        $this->end_controls_section();


        $this->start_controls_section( 'section_content_project_fitemlist', [
            'label' => esc_html__( 'Project Item List', 'kewi-extra' ),
        ] ); 

        $this->add_control( 'projectItems', [
            'label'       => esc_html__( 'Service Single Item', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'service-title'        => esc_html__( 'Interior Design', 'kewi-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'project-title',
                    'label'       => esc_html__( 'Title', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Interior Design', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter Title', 'kewi-extra' )
                ],

                [
                    'name'        => 'project-des',
                    'label'       => esc_html__( 'Short Description', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Our Sustainable Construction Advisors', 'kewi-extra' ),
                    'label_block' => true,
                    'description' => esc_html__( 'Enter Description', 'kewi-extra' )
                ],


                [
                    'name'        => 'project-image',
                    'label'       => esc_html__( 'Service Image', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        'url' => \Elementor\Utils::get_placeholder_image_src(),
                    ],

                    'description' => esc_html__( 'Upload project image', 'kewi-extra' )
                ],
                

                [
                    'name'        => 'project-link',
                    'label'       => esc_html__( 'Project Button Link', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::URL,
                    'placeholder' => __( 'https://your-link.com', 'kewi-extra' ),
                    'default'     => [
                        'url' => '#',
                    ],
                ],


            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();


        // ===================== Title ======================//

        $this->start_controls_section( 'title_style', [
            'label' => __( 'Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '
                {{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading,
                {{WRAPPER}} .__title
            ',
        ] );


        $this->add_control( 'title_color', [
            'label'     => __( 'Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Title Style


        // ===================== Subtitle Style ========================//
        $this->start_controls_section( 'sub_title_style', [
            'label' => __( 'Sub Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_sub_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading',
        ] );

        $this->add_control( 'sub_title_color', [
            'label'     => __( 'Sub Title Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading' => 'color: {{VALUE}}',
            ],

        ] );

        $this->end_controls_section(); //End Subtitle Style

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $serviceItems = $settings['serviceItems'];

        extract($settings); 


		
		?>

            
            <!-- project-area -->
            <section class="project-area">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="section-title white-title mb-80">
                                <span class="sub-title"><?php echo $settings['subtitle']; ?></span>
                                <h2 class="title"><?php echo wp_kses_post( $settings['title'] ); ?></h2>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="container-fluid p-0">
                    <div class="row g-0">
                        <div class="col-lg-6">

                            <div class="sticky-wrap" id="sticky_item">
                                <div id="tab-1" class="project-img" data-background="<?php echo esc_url( $settings['project_1']['url'] ); ?>">
                                </div>
                                <div id="tab-2" class="project-img" data-background="<?php echo esc_url( $settings['project_2']['url'] ); ?>">
                                </div>
                                <div id="tab-3" class="project-img" data-background="<?php echo esc_url( $settings['project_3']['url'] ); ?>">
                                </div>
                            </div>

                        </div>
                        <div class="col-lg-6 sub-bg">
                            <div class="project-content-wrap">


                                <div class="project-content active" data-tab="tab-1">
                                    <div class="hidden-img">
                                        <img src="<?php echo esc_url( $settings['project_1']['url'] ); ?>" alt="img">
                                    </div>
                                    <span>highlighted</span>
                                    <h2 class="title"><a href="project-details.html" class="underline-effect">Le Eduardo Bound Mountain</a></h2>
                                    <p>Our Sustainable Construction Advisors provide sustainable construction expertise to our building, civil & industrial project teams the SCAs work collaboratively.</p>
                                    <ul class="list-wrap">
                                        <li><span>Duration</span>6 Month</li>
                                        <li><span>Price</span>$25,000,00</li>
                                        <li><span>Designer</span>Hilixon</li>
                                    </ul>
                                </div>

                                <div class="project-content" data-tab="tab-2">
                                    <div class="hidden-img">
                                        <img src="<?php echo esc_url( $settings['project_2']['url'] ); ?>" alt="img">
                                    </div>
                                    <span>highlighted</span>
                                    <h2 class="title"><a href="project-details.html" class="underline-effect">Amboni Yellow Tower</a></h2>
                                    <p>Our Sustainable Construction Advisors provide sustainable construction expertise to our building, civil & industrial project teams the SCAs work collaboratively.</p>
                                    <ul class="list-wrap">
                                        <li><span>Duration</span>8 Month</li>
                                        <li><span>Price</span>$99,000,00</li>
                                        <li><span>Designer</span>Alonso</li>
                                    </ul>
                                </div>

                                <div class="project-content" data-tab="tab-3">
                                    <div class="hidden-img">
                                        <img src="<?php echo esc_url( $settings['project_3']['url'] ); ?>" alt="img">
                                    </div>
                                    <span>highlighted</span>
                                    <h2 class="title"><a href="project-details.html" class="underline-effect">Pablo Escober Town Hall</a></h2>
                                    <p>Our Sustainable Construction Advisors provide sustainable construction expertise to our building, civil & industrial project teams the SCAs work collaboratively.</p>
                                    <ul class="list-wrap">
                                        <li><span>Duration</span>9 Month</li>
                                        <li><span>Price</span>$99,999,00</li>
                                        <li><span>Designer</span>Mewsi</li>
                                    </ul>
                                </div>


                            </div>
                        </div>
                    </div>
                </div>
            </section>
            <!-- project-area-end -->





	<?php 


	}
				

}

