<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_service_list extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-service-list';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Service List', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {

        $this->start_controls_section( 'section_content_serlist', [
            'label' => esc_html__( 'Section Title', 'kewi-extra' ),
        ] );


        $this->add_control( 'title', [
            'label'       => __( 'Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'What We Provide', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'kewi-extra' ),

        ] );


        $this->end_controls_section();



        $this->start_controls_section( 'section_content_servicelist', [
            'label' => esc_html__( 'List Items', 'kewi-extra' ),
        ] ); 


        $this->add_control( 'listItems', [
            'label'       => esc_html__( 'Add List item', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'list-title'        => esc_html__( '3D Modules', 'kewi-extra' ),
                ]
            ],

            'fields'      => [
                [
                    'name'        => 'list-title',
                    'label'       => esc_html__( 'List Title', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'description' => esc_html__( 'Enter Title', 'kewi-extra' )
                ],

                [
                    'name'        => 'list-link',
                    'label'       => esc_html__( 'List Link', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::URL,
                    'placeholder' => __( 'https://your-link.com', 'kewi-extra' ),
                    'default'     => [
                        'url' => '#',
                    ],
                ],
                




            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $listItems = $settings['listItems'];

        extract($settings); 


		
		?>

        
        <div class="services-widget">
            <h4 class="widget-title"><?php echo wp_kses_post( $settings['title'] ); ?></h4>
            <div class="services-cat-list">
                <ul class="list-wrap">

                    <?php
                        foreach ( $listItems as $item ):
                    ?>

                    <li>
                        <a href="<?php echo esc_url( $item['list-link']['url'] ) ?>">I<?php echo $item['list-title'] ?><i class="fas fa-chevron-right"></i></a>
                    </li>

                     <?php endforeach; ?> 


                </ul>
            </div>
        </div>



	<?php 


	}
				

}

