<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_skill_about extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-about-skill';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Skill About: 01', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_title_about', [
            'label' => esc_html__( 'Section Title', 'kewi-extra' ),
        ] );


        $this->add_control( 'subtitle', [
            'label'       => __( 'Sub Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'default'     => __( 'About Us', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section subtitle here.", 'kewi-extra' ),
        ] );

        $this->add_control( 'title', [
            'label'       => __( 'Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'IWhat ets us apart from the rest is our visionary', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'kewi-extra' ),

        ] );

        $this->add_control( 'description', [
            'label'       => __( 'Description', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Our Sustainable Construction Advisors provide sustainable construction expertise', 'kewi-extra' ),
            'label_block' => true,
        ] );


        $this->add_control( 'about_feature_image', [
            'label'   => __( 'Choose Image', 'kewi-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );


        $this->end_controls_section();


        $this->start_controls_section( 'section_content_counterskill_itemlist', [
            'label' => esc_html__( 'Counter Item List', 'kewi-extra' ),
        ] ); 

        $this->add_control( 'counterItems', [
            'label'       => esc_html__( 'Skill Bar Item', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'counter-title'        => esc_html__( 'Realized Projects', 'kewi-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'counter-title',
                    'label'       => esc_html__( 'Title', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Work Progress', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter Title', 'kewi-extra' )
                ],

                [
                    'name'        => 'progress-number',
                    'label'       => esc_html__( 'Set Progress Bar Parcentage in Number', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::NUMBER,
                    'min'         => 1,
                    'max'         => 100,
                    'step'        => 5,
                    'default'     => 65,
                ],

                [
                    'name'        => 'count-number',
                    'label'       => esc_html__( 'Set Counter Number', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::NUMBER,
                    'min'         => 1,
                    'max'         => 100,
                    'step'        => 5,
                    'default'     => 65,
                ],



            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();



        // ===================== Title ======================//

        $this->start_controls_section( 'title_style', [
            'label' => __( 'Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '
                {{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading,
                {{WRAPPER}} .__title
            ',
        ] );


        $this->add_control( 'title_color', [
            'label'     => __( 'Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Title Style


        // ===================== Subtitle Style ========================//
        $this->start_controls_section( 'sub_title_style', [
            'label' => __( 'Sub Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_sub_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading',
        ] );

        $this->add_control( 'sub_title_color', [
            'label'     => __( 'Sub Title Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading' => 'color: {{VALUE}}',
            ],

        ] );

        $this->end_controls_section(); //End Subtitle Style

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $counterItems = $settings['counterItems'];

        extract($settings); 


		
		?>


           <!-- skill-area -->
            <section class="skill-area pt-120 pb-120">
                <div class="container">
                    <div class="row align-items-center">
                        <div class="col-lg-6">

                            <div class="skill-img">
                                <img src="<?php echo esc_url( $settings['about_feature_image']['url'] ); ?>" alt="img">
                            </div>

                        </div>
                        <div class="col-lg-6">
                            <div class="skill-content">
                                <div class="section-title mb-40">
                                    <span class="sub-title"><?php echo $settings['subtitle']; ?></span>
                                    <h2 class="title"><?php echo wp_kses_post( $settings['title'] ); ?></h2>
                                </div>
                                <p><?php echo wp_kses_post( $settings['description'] ); ?></p>


                                <div class="skill-item-wrap">

                                <?php
                                    foreach ( $counterItems as $item ):
                                ?>

                                

                                    <div class="skill-item">
                                        <div class="chart-two" data-percent="<?php echo $item['progress-number']; ?>">
                                            <span class="percentage"><?php echo $item['count-number']; ?><sup>%</sup></span>
                                        </div>
                                        <p><?php echo $item['counter-title']; ?></p>
                                    </div>

                                <?php endforeach; ?>

                                </div>

                              


                            </div>
                        </div>
                    </div>
                </div>
            </section>
            <!-- skill-area-end -->


	

	<?php 


	}
				

}

