<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_slide_one extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-slide-onee';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Slider: 01', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_slider_one', [
            'label' => esc_html__( 'Slide Item Content', 'kewi-extra' ),
        ] );

        $this->add_control( 'sliderItems', [
            'label'       => esc_html__( 'Slider One Items', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'title'        => esc_html__( 'The Satirical', 'kewi-extra' ),
                ]
            ],

            'fields'      => [
                [
                    'name'        => 'title',
                    'label'       => esc_html__( 'Title', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'description' => esc_html__( 'Enter Title', 'kewi-extra' )
                ],
                
                [
                    'name'        => 'image',
                    'label'       => esc_html__( 'Slider Image', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        'url' => \Elementor\Utils::get_placeholder_image_src(),
                    ],

                    'description' => esc_html__( 'Upload slide image', 'kewi-extra' )
                ],
                
                [
                    'name'        => 'author-name',
                    'label'       => esc_html__( 'Author Name', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXT,
                    'default'     => __( 'Aristo Melmon', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter Author Name', 'kewi-extra' )
                ],

                [
                    'name'        => 'author-position',
                    'label'       => esc_html__( 'Author Position', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXT,
                    'default'     => __( 'Designer', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter Author Position', 'kewi-extra' )
                ],

                [
                    'name'        => 'author-image',
                    'label'       => esc_html__( 'Slider Author Image', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        'url' => \Elementor\Utils::get_placeholder_image_src(),
                    ],
                    'description' => esc_html__( 'Upload slide author image', 'kewi-extra' )
                ],
                


            ],
            'title_field' => "{{name}}"
        ] );

        $this->end_controls_section(); 



        // ===================== Title ======================//

        $this->start_controls_section( 'title_style', [
            'label' => __( 'Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '
                {{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading,
                {{WRAPPER}} .__title
            ',
        ] );


        $this->add_control( 'title_color', [
            'label'     => __( 'Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Title Style


        // ===================== Subtitle Style ========================//
        $this->start_controls_section( 'sub_title_style', [
            'label' => __( 'Sub Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_sub_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading',
        ] );

        $this->add_control( 'sub_title_color', [
            'label'     => __( 'Sub Title Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading' => 'color: {{VALUE}}',
            ],

        ] );

        $this->end_controls_section(); //End Subtitle Style

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $slider_items = $settings['sliderItems'];

        extract($settings); 


		
		?>


            <!-- slider-area -->
            <section class="slider-area theme-slide-style-one">

                <div class="slider-active">


                    <?php
                        foreach ( $slider_items as $item ):
                    ?>

                    <div class="single-slider slider-bg" data-background="<?php echo esc_url( $item['image']['url'] ); ?>" style="background-image:url(<?php echo esc_url( $item['image']['url'] ); ?>;)">


                        <div class="container">
                            <div class="row">
                                <div class="col-xl-7 col-lg-8">
                                    <div class="slider-content">

                                        <h2 class="title" data-animation="fadeInUp" data-delay=".3s">
                                            <?php echo wp_kses_post( $item['title'] ); ?>
                                        </h2>

                                        <div class="slider-avatar" data-animation="fadeInUp" data-delay=".6s">
                                            <div class="thumb">
                                                <img src="<?php echo esc_url( $item['author-image']['url'] ); ?>" alt="img">
                                            </div>
                                            <div class="content">
                                                <h6 class="name"><?php echo esc_html( $item['author-name'] ); ?></h6>
                                                <span><?php echo esc_html( $item['author-position'] ); ?></span>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <?php endforeach; ?>    


                </div>


                <div class="slick-counter"><span class="current"></span> / <span class="total"></span></div>

            </section>
            <!-- slider-area-end -->


	

	<?php 


	}
				

}

