<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_team extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-team-sec';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Team: 01', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_title_team', [
            'label' => esc_html__( 'Section Title and Button', 'kewi-extra' ),
        ] );


        $this->add_control( 'subtitle', [
            'label'       => __( 'Sub Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'default'     => __( 'About Us', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section subtitle here.", 'kewi-extra' ),
        ] );

        $this->add_control( 'title', [
            'label'       => __( 'Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'kewi-extra' ),

        ] );

        $this->add_control( 'join_btn_text', [
            'label'       => __( 'Bottom Button Label', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type your button label here', 'kewi-extra' ),
            'default'     => __( 'Join Us Today', 'kewi-extra' ),
        ] );

        $this->add_control( 'join_btn_link', [
            'label'       => __( 'Bottom Button Link', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::URL,
            'placeholder' => __( 'https://your-link.com', 'kewi-extra' ),
            'default'     => [
                'url' => '#',
            ],
        ] );

        $this->add_control(
            'team_bg_img',
            [
                'label' => esc_html__('Team Section Background Image','restlycore'),
                'type'=> \Elementor\Controls_Manager::MEDIA,
                'default' => [
                  'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'label_block' => true,
            ]
        );

        


        $this->end_controls_section();


        $this->start_controls_section( 'section_content_team_itemlist', [
            'label' => esc_html__( 'Single Team Member Item', 'kewi-extra' ),
        ] ); 

        $this->add_control( 'teamItems', [
            'label'       => esc_html__( 'Team Member Item', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'member-name'        => esc_html__( 'Evelyn Rose', 'kewi-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'member-name',
                    'label'       => esc_html__( 'Title', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Evelyn Rose', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter Member Name', 'kewi-extra' )
                ],

                [
                    'name'        => 'member-position',
                    'label'       => esc_html__( 'Member Position', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Our Sustainable Construction Advisors', 'kewi-extra' ),
                    'label_block' => true,
                    'description' => esc_html__( 'Enter Position', 'kewi-extra' )
                ],


                [
                    'name'        => 'member-image',
                    'label'       => esc_html__( 'Team Member Image', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        'url' => \Elementor\Utils::get_placeholder_image_src(),
                    ],

                    'description' => esc_html__( 'Upload member image', 'kewi-extra' )
                ],

                
                [
                    'name'        => 'team-link',
                    'label'       => esc_html__( 'Enter Member Profile Link', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::URL,
                    'placeholder' => __( 'https://your-link.com', 'kewi-extra' ),
                    'default'     => [
                        'url' => '#',
                    ],
                ],

                [
                    'name'        => 'fb-link',
                    'label'       => esc_html__( 'Enter Member Facebook Link', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::URL,
                    'placeholder' => __( 'https://your-link.com', 'kewi-extra' ),
                    'default'     => [
                        'url' => '#',
                    ],
                ],

                [
                    'name'        => 'tw-link',
                    'label'       => esc_html__( 'Enter Member Twitter Link', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::URL,
                    'placeholder' => __( 'https://your-link.com', 'kewi-extra' ),
                    'default'     => [
                        'url' => '#',
                    ],
                ],

                [
                    'name'        => 'in-link',
                    'label'       => esc_html__( 'Enter Member Instagram Link', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::URL,
                    'placeholder' => __( 'https://your-link.com', 'kewi-extra' ),
                    'default'     => [
                        'url' => '#',
                    ],
                ],

                [
                    'name'        => 'be-link',
                    'label'       => esc_html__( 'Enter Member Behance Link', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::URL,
                    'placeholder' => __( 'https://your-link.com', 'kewi-extra' ),
                    'default'     => [
                        'url' => '#',
                    ],
                ],





            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();


        // ===================== Title ======================//

        $this->start_controls_section( 'title_style', [
            'label' => __( 'Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '
                {{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading,
                {{WRAPPER}} .__title
            ',
        ] );


        $this->add_control( 'title_color', [
            'label'     => __( 'Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Title Style


        // ===================== Subtitle Style ========================//
        $this->start_controls_section( 'sub_title_style', [
            'label' => __( 'Sub Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_sub_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading',
        ] );

        $this->add_control( 'sub_title_color', [
            'label'     => __( 'Sub Title Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading' => 'color: {{VALUE}}',
            ],

        ] );

        $this->end_controls_section(); //End Subtitle Style

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $teamItems = $settings['teamItems'];

        extract($settings); 


		
		?>

         
            <!-- team-area -->
            <section class="team-area team-bg" data-background="<?php echo esc_url( $settings['team_bg_img']['url'] ); ?>" style="background-image: url(<?php echo esc_url( $settings['team_bg_img']['url'] ); ?>);">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="section-title mb-80">
                                 <span class="sub-title"><?php echo $settings['subtitle']; ?></span>
                                <h2 class="title"><?php echo wp_kses_post( $settings['title'] ); ?></h2>
                            </div>
                        </div>
                    </div>
                    <div class="team-item-wrap">
                        <div class="row">

                            <?php
                                foreach ( $teamItems as $item ):
                            ?>

                            <div class="col-lg-3 col-sm-6">
                                <div class="team-item">
                                    <div class="team-thumb">
                                        <img src="<?php echo esc_url( $item['member-image']['url'] ); ?>" alt="img">
                                        <div class="team-social">
                                            <ul class="list-wrap">
                                                <li><a href="<?php echo esc_url( $item['fb-link']['url'] ) ?>"><i class="fab fa-facebook-f"></i></a></li>
                                                <li><a href="<?php echo esc_url( $item['tw-link']['url'] ) ?>"><i class="fab fa-twitter"></i></a></li>
                                                <li><a href="<?php echo esc_url( $item['in-link']['url'] ) ?>"><i class="fab fa-linkedin"></i></a></li>
                                                <li><a href="<?php echo esc_url( $item['be-link']['url'] ) ?>"><i class="fab fa-behance"></i></a></li>
                                            </ul>
                                        </div>
                                    </div>
                                    <div class="team-content">
                                        <span><?php echo wp_kses_post( $item['member-position'] ); ?></span>
                                        <h4 class="title"><a href="<?php echo esc_url( $item['team-link']['url'] ) ?>" class="underline-effect"><?php echo wp_kses_post( $item['member-name'] ); ?></a></h4>
                                    </div>
                                </div>
                            </div>

                            <?php endforeach; ?>  


                        </div>
                        <div class="join-btn text-center mt-30">
                            <a href="<?php echo esc_url( $settings['join_btn_link']['url'] ) ?>" class="btn"><?php echo $settings['join_btn_text'] ?></a>
                        </div>
                    </div>
                </div>
            </section>
            <!-- team-area-end -->




	<?php 


	}
				

}

