<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_banner_three extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-banner-home-three';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Three Banner', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_banner_three', [
            'label' => esc_html__( 'Banner Content', 'kewi-extra' ),
        ] );


        $this->add_control( 'title', [
            'label'       => __( 'Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'kewi-extra' ),

        ] );

        $this->add_control( 'sub-title', [
            'label'       => __( 'Bottom Sub Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section sub title here.", 'kewi-extra' ),

        ] );

        $this->add_control( 'banner_feature_image', [
            'label'   => __( 'Choose Banner Bcakground Image', 'kewi-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );


        $this->add_control(
			'video_box_img',
			[
			    'label' => esc_html__('Video Open Icon','restlycore'),
			    'type'=> \Elementor\Controls_Manager::MEDIA,
			    'default' => [
				  'url' => \Elementor\Utils::get_placeholder_image_src(),
			    ],
                'label_block' => true,
			]
		);


        $this->add_control(
            'video_link', [
                'label' => __( 'Insert Self Hosted Video URL Link in Video format(eg. mp4/flv etc).', 'gazania-extra' ),
                'type'        => \Elementor\Controls_Manager::URL,

                'default'     => [
                    'url' => 'http://commondatastorage.googleapis.com/gtv-videos-bucket/sample/BigBuckBunny.mp4',
                ],
                
                'description' => esc_html__( 'Enter Video URL', 'gazania-extra' )
            ]
        );


        $this->end_controls_section();


        $this->start_controls_section( 'section_content_brand_banner_three', [
            'label' => esc_html__( 'Banner 3 Brand Items', 'kewi-extra' ),
        ] ); 


        $this->add_control( 'brandItems', [
            'label'       => esc_html__( 'Add brand item', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'brand-title'        => esc_html__( 'Brand 1', 'kewi-extra' ),
                ]
            ],

            'fields'      => [
                [
                    'name'        => 'brand-title',
                    'label'       => esc_html__( 'Title', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'description' => esc_html__( 'Enter Title', 'kewi-extra' )
                ],
                
                [
                    'name'        => 'brand-image',
                    'label'       => esc_html__( 'Brand Image', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        'url' => \Elementor\Utils::get_placeholder_image_src(),
                    ],

                    'description' => esc_html__( 'Upload brand image', 'kewi-extra' )
                ],




            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();


		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

		$brandItems = $settings['brandItems'];

        extract($settings); 


		
		?>


    <script type="text/javascript">
    
        jQuery(document).ready(function ($) {
            
            $('.brand-active-three').slick({
                dots: false,
                infinite: true,
                speed: 1000,
                autoplay: true,
                arrows: false,
                slidesToShow: 5,
                slidesToScroll: 1,
                responsive: [
                    {
                        breakpoint: 1200,
                        settings: {
                            slidesToShow: 5,
                            slidesToScroll: 1,
                            infinite: true,
                        }
                    },
                    {
                        breakpoint: 992,
                        settings: {
                            slidesToShow: 4,
                            slidesToScroll: 1
                        }
                    },
                    {
                        breakpoint: 767,
                        settings: {
                            slidesToShow: 3,
                            slidesToScroll: 1,
                            arrows: false,
                        }
                    },
                    {
                        breakpoint: 575,
                        settings: {
                            slidesToShow: 2,
                            slidesToScroll: 1,
                            arrows: false,
                        }
                    },
                ]
            });

        });

    </script> 


            <!-- banner-area -->
            <section class="banner-area-two banner-bg-two" data-background="<?php echo esc_url( $settings['banner_feature_image']['url'] ); ?>" style="background-image:url(<?php echo esc_url( $settings['banner_feature_image']['url'] ); ?>;)">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="banner-content-two">
                                <h1 class="main-title"><?php echo wp_kses_post( $settings['title'] ); ?></h1>
                                <div class="banner-content-inner">
                                    <div class="left-side-content">
                                        <h2 class="title"><?php echo wp_kses_post( $settings['sub-title'] ); ?></h2>
                                    </div>
                                    <div class="banner-video-wrap">
                                        <div class="video-info">
                                            <input id="video_check" type="checkbox">
                                            <div class="intro-icon">
                                                <span class="video-icon"><img src="<?php echo esc_url( $settings['video_box_img']['url'] ); ?>" alt="img"></span>
                                                <span class="video-icon close-video-icon">x</span>
                                            </div>
                                            <div class="video">
                                                <video src="<?php echo esc_url( $settings['video_link']['url'] ) ?>" loop muted autoplay playsinline></video>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- brand-area -->
                <div class="brand-area-three pt-120">
                    <div class="container">
                        <div class="row brand-active brand-active-three">

                            <?php
		                        foreach ( $brandItems as $item ):
		                    ?>

		                    <div class="col-12">
		                        <div class="brand-item">
		                            <img src="<?php echo esc_url( $item['brand-image']['url'] ); ?>" alt="img">
		                        </div>
		                    </div>

		                    <?php endforeach; ?>  

                        </div>
                    </div>
                </div>
                <!-- brand-area-end -->

            </section>
            <!-- banner-area-end -->


	<?php 


	}
				

}

