<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_timeline extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-home-timeline';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Timeline: 01', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_timeline', [
            'label' => esc_html__( 'Section Title', 'kewi-extra' ),
        ] );


        $this->add_control( 'subtitle', [
            'label'       => __( 'Sub Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'default'     => __( 'About Us', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section subtitle here.", 'kewi-extra' ),
        ] );

        $this->add_control( 'title', [
            'label'       => __( 'Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'kewi-extra' ),

        ] );

        $this->add_control( 'description', [
            'label'       => __( 'Description', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Our Sustainable Construction Advisors provide sustainable construction expertise', 'kewi-extra' ),
            'label_block' => true,
        ] );

        $this->add_control( 'btn_text', [
            'label'       => __( 'Button Label', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type your button label here', 'kewi-extra' ),
            'default'     => __( 'Get in touch', 'kewi-extra' ),
        ] );

        $this->add_control( 'btn_link', [
            'label'       => __( 'Button Link', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::URL,
            'placeholder' => __( 'https://your-link.com', 'kewi-extra' ),
            'default'     => [
                'url' => '#',
            ],
        ] );


        $this->add_control(
            'display_img',
            [
                'label' => esc_html__('Display image', 'ennlil-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'ennlil-extra'),
                'label_off' => esc_html__('No', 'ennlil-extra'),
                'default' => 'yes',
            ]
        );

        
        $this->add_control( 'timeline_bg_image', [
            'label'   => __( 'Choose Image', 'kewi-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );

        $this->add_control( 'timeline_bg_color', [
            'label'     => __( 'Set Section Background Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'default'   => __( '#f8f8f8', 'kewi-extra' ),
            'selectors' => [
                '{{WRAPPER}} .about-area-three' => 'background: {{VALUE}}',
            ],

        ] );



        $this->end_controls_section();


        $this->start_controls_section( 'section_content_timeline_list', [
            'label' => esc_html__( 'Timeline Item List', 'kewi-extra' ),
        ] ); 

        $this->add_control( 'timelineItems', [
            'label'       => esc_html__( 'Timeline Single Item', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'timeline-year'        => esc_html__( '2014', 'kewi-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'timeline-year',
                    'label'       => esc_html__( 'Year', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( '2014', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter Year', 'kewi-extra' )
                ],

                [
                    'name'        => 'timeline-title',
                    'label'       => esc_html__( 'Title', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Interior Design', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter Title', 'kewi-extra' )
                ],

                [
                    'name'        => 'timeline-des',
                    'label'       => esc_html__( 'Short Description', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Our Sustainable Construction Advisors', 'kewi-extra' ),
                    'label_block' => true,
                    'description' => esc_html__( 'Enter Description', 'kewi-extra' )
                ],



            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();


        // ===================== Title ======================//

        $this->start_controls_section( 'title_style', [
            'label' => __( 'Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '
                {{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading,
                {{WRAPPER}} .__title
            ',
        ] );


        $this->add_control( 'title_color', [
            'label'     => __( 'Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Title Style


        // ===================== Subtitle Style ========================//
        $this->start_controls_section( 'sub_title_style', [
            'label' => __( 'Sub Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_sub_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading',
        ] );

        $this->add_control( 'sub_title_color', [
            'label'     => __( 'Sub Title Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading' => 'color: {{VALUE}}',
            ],

        ] );

        $this->end_controls_section(); //End Subtitle Style

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $timelineItems = $settings['timelineItems'];

        extract($settings); 


		
		?>

            <!-- about-area -->
            <section class="about-area-three">
                <div class="container">
                    <div class="row align-items-center">
                        <div class="col-lg-6 order-0 order-lg-2">
                            <div class="about-list-wrap">
                                <ul class="list-wrap">

                                    <?php
                                        foreach ( $timelineItems as $item ):
                                    ?>

                                    <li>
                                        <div class="about-list-item">
                                            <h2 class="date"><?php echo wp_kses_post( $item['timeline-year'] ); ?></h2>
                                            <h4 class="title"><?php echo wp_kses_post( $item['timeline-title'] ); ?></h4>
                                            <p><?php echo wp_kses_post( $item['timeline-des'] ); ?></p>
                                        </div>
                                    </li>

                                    <?php endforeach; ?>  

                                </ul>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="about-content-three">
                                <div class="section-title mb-40">
                                    <span class="sub-title"><?php echo $settings['subtitle']; ?></span>
                                    <h2 class="title"><?php echo wp_kses_post( $settings['title'] ); ?></h2>
                                </div>

                                <p><?php echo wp_kses_post( $settings['description'] ); ?></p>

                                <a href="<?php echo esc_url( $settings['btn_link']['url'] ) ?>" class="btn"><span><?php echo $settings['btn_text'] ?></span></a>
                            </div>
                        </div>
                    </div>


                    <?php if($display_img == 'yes'): ?>  
                    <div class="about-shape">
                        <img src="<?php echo esc_url( $settings['timeline_bg_image']['url'] ); ?>" alt="img">
                    </div>
                    <?php endif; ?> 



                </div>
            </section>
            <!-- about-area-end -->


	<?php 


	}
				

}

