<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_banner_two extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-banner-home-two';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Two Banner', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_banner_two', [
            'label' => esc_html__( 'Banner Content', 'kewi-extra' ),
        ] );


        $this->add_control( 'title', [
            'label'       => __( 'Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'kewi-extra' ),

        ] );

        $this->add_control( 'banner_feature_image', [
            'label'   => __( 'Choose Image', 'kewi-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );

        $this->add_control( 'btn_text', [
            'label'       => __( 'Button Label', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type your button label here', 'kewi-extra' ),
            'default'     => __( 'Get in touch', 'kewi-extra' ),
        ] );

        $this->add_control( 'btn_link', [
            'label'       => __( 'Button Link', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::URL,
            'placeholder' => __( 'https://your-link.com', 'kewi-extra' ),
            'default'     => [
                'url' => '#',
            ],
        ] );


        $this->end_controls_section();


        $this->start_controls_section( 'section_content_banner_author', [
            'label' => esc_html__( 'Author Section', 'kewi-extra' ),
        ] ); 


        $this->add_control( 'banner_author_image', [
            'label'   => __( 'Choose Image', 'kewi-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );


        $this->add_control( 'banner_author_name', [
            'label'       => __( 'Author Name', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type author name here', 'kewi-extra' ),
            'default'     => __( 'Aristo Melmon', 'kewi-extra' ),
        ] );


        $this->add_control( 'banner_author_position', [
            'label'       => __( 'Author Position', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type author position here', 'kewi-extra' ),
            'default'     => __( 'Designer', 'kewi-extra' ),
        ] );






        $this->end_controls_section();



		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        extract($settings); 


		
		?>


        <!-- banner-area -->
        <section class="banner-area">
            <div class="banner-bg jarallax" data-background="<?php echo esc_url( $settings['banner_feature_image']['url'] ); ?>" style="background-image:url(<?php echo esc_url( $settings['banner_feature_image']['url'] ); ?>;)"></div>
            <div class="container">
                <div class="row">
                    <div class="col-xxl-5 col-xl-6 col-lg-8">
                        <div class="banner-content">
                            <div class="banner-avatar">
                                <div class="thumb">
                                    <img src="<?php echo esc_url( $settings['banner_author_image']['url'] ); ?>" alt="img">
                                </div>
                                <div class="content">
                                    <h6 class="name"><?php echo $settings['banner_author_name']; ?></h6>
                                    <span><?php echo $settings['banner_author_position']; ?></span>
                                </div>
                            </div>
                            <h2 class="title"><?php echo wp_kses_post( $settings['title'] ); ?></h2>
                            <a href="<?php echo esc_url( $settings['btn_link']['url'] ) ?>" class="btn"><span><?php echo $settings['btn_text'] ?></span></a>
                        </div>
                    </div>
                </div>
            </div>
        </section>
        <!-- banner-area-end -->



	<?php 


	}
				

}

