<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_two_brand extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-brand-home-two';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Brands Grid: 01', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_title_brandtwo', [
            'label' => esc_html__( 'Section Title', 'kewi-extra' ),
        ] );

        $this->add_control( 'title', [
            'label'       => __( 'Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'We backed by 1000+ users', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'kewi-extra' ),

        ] );

        $this->end_controls_section();


        $this->start_controls_section( 'section_content_brand_two_home', [
            'label' => esc_html__( 'Brand Items', 'kewi-extra' ),
        ] ); 


        $this->add_control( 'brandItems', [
            'label'       => esc_html__( 'Add brand item', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'brand-title'        => esc_html__( 'Brand 1', 'kewi-extra' ),
                ]
            ],

            'fields'      => [
                [
                    'name'        => 'brand-title',
                    'label'       => esc_html__( 'Title', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'description' => esc_html__( 'Enter Title', 'kewi-extra' )
                ],
                
                [
                    'name'        => 'brand-image',
                    'label'       => esc_html__( 'Brand Image', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        'url' => \Elementor\Utils::get_placeholder_image_src(),
                    ],

                    'description' => esc_html__( 'Upload brand image', 'kewi-extra' )
                ],




            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $brandItems = $settings['brandItems'];

        extract($settings); 


		
		?>


            <!-- brand-area -->
            <div class="brand-area-two">
                <div class="container">
                    <div class="row justify-content-center">
                        <div class="col-lg-6">
                            <div class="section-title text-center mb-80">
                                <h2 class="title"><?php echo wp_kses_post( $settings['title'] ); ?></h2>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="brand-item-wrap">
                                <ul class="list-wrap">

                                    <?php
                                        foreach ( $brandItems as $item ):
                                    ?>
                                    <li>
                                        <div class="brand-item">
                                            <img src="<?php echo esc_url( $item['brand-image']['url'] ); ?>" alt="img">
                                        </div>
                                    </li>

                                    <?php endforeach; ?> 

                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <!-- brand-area-end -->


	<?php 


	}
				

}

