<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_services_two extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-services-two';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Services: 02', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_services_two_itemlist', [
            'label' => esc_html__( 'Services Item List', 'kewi-extra' ),
        ] ); 

        $this->add_control(
            'all_btn_show',
            [
                'label' => esc_html__( 'Show all button', 'kewi-extra' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'kewi-extra' ),
                'label_off' => esc_html__( 'Hide', 'kewi-extra' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control( 'serviceItems', [
            'label'       => esc_html__( 'Service Single Item', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'service-title'        => esc_html__( 'Interior Design', 'kewi-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'service-title',
                    'label'       => esc_html__( 'Title', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Interior Design', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter Title', 'kewi-extra' )
                ],

                [
                    'name'        => 'service-des',
                    'label'       => esc_html__( 'Short Description', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Our Sustainable Construction Advisors', 'kewi-extra' ),
                    'label_block' => true,
                    'description' => esc_html__( 'Enter Description', 'kewi-extra' )
                ],

                [
                    'name'        => 'service-number',
                    'label'       => esc_html__( 'Service Number', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( '01', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter Number', 'kewi-extra' )
                ],

                [
                    'name'        => 'service-image',
                    'label'       => esc_html__( 'Service Image', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        'url' => \Elementor\Utils::get_placeholder_image_src(),
                    ],

                    'description' => esc_html__( 'Upload service image', 'kewi-extra' )
                ],
                

                [
                    'name'        => 'service-link',
                    'label'       => esc_html__( 'Service Link', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::URL,
                    'placeholder' => __( 'https://your-link.com', 'kewi-extra' ),
                    'default'     => [
                        'url' => '#',
                    ],
                ],



            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();

        $this->start_controls_section( 'section_content_bottom_services', [
            'label' => esc_html__( 'Button', 'kewi-extra' ),
        ] );


        $this->add_control( 'btn-title', [
            'label'       => __( 'Button Text', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'More Services', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type button text here.", 'kewi-extra' ),

        ] );

        $this->add_control( 'btn-link', [
            'label'       => __( 'Button Link', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::URL,
            'placeholder' => __( 'https://your-link.com', 'kewi-extra' ),
            'default'     => [
                'url' => '#',
            ],
        ] );


        $this->end_controls_section();


		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $serviceItems = $settings['serviceItems'];


        extract($settings); 


		
		?>


            <!-- services-area -->
            <section class="services-area-two">
                <div class="container">
                    <div class="row justify-content-center">


                        <?php
                            foreach ( $serviceItems as $item ):
                        ?>

                        <div class="col-xl-3 col-lg-4 col-md-6">
                            <div class="services-item-two">
                                <div class="services-icon-two">

                                    <img src="<?php echo esc_url( $item['service-image']['url'] ); ?>" alt="img">

                                    <h2 class="number"><?php echo $item['service-number']; ?></h2>
                                    
                                </div>
                                <div class="services-content-two">
                                    <h2 class="title"><a href="<?php echo esc_url( $item['service-link']['url'] ) ?>" class="underline-effect"><?php echo wp_kses_post( $item['service-title'] ); ?></a></h2>
                                    <p><?php echo wp_kses_post( $item['service-des'] ); ?></p>
                                </div>
                            </div>
                        </div>

                        <?php endforeach; ?> 


                    </div>
                    

                    <?php if($settings['all_btn_show'] == 'yes' ) { ?>

                    <div class="more-services-btn text-center mt-30">
                        <a href="<?php echo esc_url( $settings['btn-link']['url'] ) ?>" class="btn"><?php echo wp_kses_post( $settings['btn-title'] ); ?></a>
                    </div>

                     <?php } ?>


                </div>
            </section>
            <!-- services-area-end -->



	<?php 


	}
				

}

