<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_what_we_do extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-what-we-do';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home What we do: 01', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {



        $this->start_controls_section( 'section_content_services_fitemlist', [
            'label' => esc_html__( 'What we  do Item List', 'kewi-extra' ),
        ] ); 

        $this->add_control( 'featureItems', [
            'label'       => esc_html__( 'Feature Single Item', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'feature-title'        => esc_html__( 'Interior Design', 'kewi-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'feature-number',
                    'label'       => esc_html__( 'Number', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( '01', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter feature number', 'kewi-extra' )
                ],


                [
                    'name'        => 'feature-title',
                    'label'       => esc_html__( 'Title', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Interior Design', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter Title', 'kewi-extra' )
                ],

                [
                    'name'        => 'feature-des',
                    'label'       => esc_html__( 'Short Description', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Our Sustainable Construction Advisors', 'kewi-extra' ),
                    'label_block' => true,
                    'description' => esc_html__( 'Enter Description', 'kewi-extra' )
                ],


                [
                    'name'        => 'feature-image',
                    'label'       => esc_html__( 'Service Image', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        'url' => \Elementor\Utils::get_placeholder_image_src(),
                    ],

                    'description' => esc_html__( 'Upload feature image', 'kewi-extra' )
                ],
                

                [
                    'name'        => 'btn-link',
                    'label'       => esc_html__( 'Feature Button Link', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::URL,
                    'placeholder' => __( 'https://your-link.com', 'kewi-extra' ),
                    'default'     => [
                        'url' => '#',
                    ],
                ],



            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();


        // ===================== Title ======================//

        $this->start_controls_section( 'title_style', [
            'label' => __( 'Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '
                {{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading,
                {{WRAPPER}} .__title
            ',
        ] );


        $this->add_control( 'title_color', [
            'label'     => __( 'Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Title Style


        // ===================== Subtitle Style ========================//
        $this->start_controls_section( 'sub_title_style', [
            'label' => __( 'Sub Title', 'kewi-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_sub_typography',
            'label'    => __( 'Typography', 'kewi-extra' ),
            'selector' => '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading',
        ] );

        $this->add_control( 'sub_title_color', [
            'label'     => __( 'Sub Title Color', 'kewi-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading' => 'color: {{VALUE}}',
            ],

        ] );

        $this->end_controls_section(); //End Subtitle Style

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $featureItems = $settings['featureItems'];

        extract($settings); 


		
		?>


            <!-- services-area -->
            <section class="services-area-five">
                <div class="container">
                    <div class="row justify-content-center">



                        <?php
                            foreach ( $featureItems as $item ):
                        ?>

                        <div class="col-xl-3 col-lg-4 col-md-6">
                            <div class="services-item-two">
                                <div class="services-icon-two">
                                    <img src="<?php echo esc_url( $item['feature-image']['url'] ); ?>" alt="img">
                                    <h2 class="number"><?php echo $item['feature-number']; ?></h2>
                                </div>
                                <div class="services-content-two">
                                    <h2 class="title"><a href="<?php echo esc_url( $item['btn-link']['url'] ) ?>" class="underline-effect"><?php echo wp_kses_post( $item['feature-title'] ); ?></a></h2>
                                    <p><?php echo wp_kses_post( $item['feature-des'] ); ?></p>
                                </div>
                            </div>
                        </div>

                        <?php endforeach; ?>  

                    </div>
                </div>
            </section>
            <!-- services-area-end -->




	<?php 


	}
				

}

