<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_portfolio_filter extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'custom-portfolio-with-filter';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Portfolio with Filter V.1', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {

		//Content tab start
        $this->start_controls_section(
            'theme_portfolio_menu_options',
            [
                'label' => esc_html__( 'Portfolio With Filter', 'kewi-extra' ),
                'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'theme_portfolio_style',
            [
                'label' => esc_html__( 'Select Portfolio Style', 'restlycore' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'one',
                'options' => [
                    'one'  => esc_html__( 'Style One', 'restlycore' ),
                    'two'  => esc_html__( 'Style Two', 'restlycore' ),
                    'three'  => esc_html__( 'Style Three', 'restlycore' ),
                    'four'  => esc_html__( 'Style Four', 'restlycore' ),
                ],
            ]
        );

        $this->add_control(
            'portfolio_title_style',
            [
                'label' => esc_html__( 'Select Title Style', 'restlycore' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'one',
                'options' => [
                    'one'  => esc_html__( 'Style One', 'restlycore' ),
                    'two'  => esc_html__( 'Style Two', 'restlycore' ),
                ],
            ]
        );

        

		
        $this->add_control(
            'theme_portfolio_item_numbers',
            [
                'label' => esc_html__( 'Display Items', 'kewi-extra' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 10,
                'step' => 1,
                'default' => 9,
            ]
        );
		
        $this->add_control(
            'theme_portfolio_filter_show',
            [
                'label' => esc_html__( 'Show Filter', 'kewi-extra' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'kewi-extra' ),
                'label_off' => esc_html__( 'Hide', 'kewi-extra' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
		
        $this->add_control(
            'theme_portfolio_navigation_show',
            [
                'label' => esc_html__( 'Show Navigation', 'kewi-extra' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'kewi-extra' ),
                'label_off' => esc_html__( 'Hide', 'kewi-extra' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->add_control(
            'theme_portfolio_menu_align',
            [
                'label' => __( 'Alignment', 'kewi-extra' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => __( 'Left', 'kewi-extra' ),
                        'icon' => 'fas fa-align-left',
                    ],
                    'center' => [
                        'title' => __( 'Center', 'kewi-extra' ),
                        'icon' => 'fas fa-align-center',
                    ],
                    'right' => [
                        'title' => __( 'Right', 'kewi-extra' ),
                        'icon' => 'fas fa-align-right',
                    ],
                ],
                'default' => 'left',
                'toggle' => true,
                'selectors' => [
                    '{{WRAPPER}} .project-nav.inner-project-nav .list-wrap' => 'justify-content: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'portfolio_img_height',
            [
                'label' =>esc_html__( 'Set Portfolio Image Height', 'kewi-extra' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 400,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 400,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 400,
                    'unit' => 'px',
                ],
                
                'default'  => [
                    'unit' => 'px',
                    'size' => 400,
                ],
                
                'selectors' => [
                    '{{WRAPPER}} .theme-portfolio-section-wrap .project-thumb-four img' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        
        $this->end_controls_section();
		
		

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();
	
		$dynamic_num = rand(799523678395, 3762272956024);
		
		?>

		<script>
			jQuery(window).ready(function($) {
			 
                'use strict';

				jQuery('.theme-portfolio-section-wrap .project-filter-navv ul#projects-filter-menu-new li').on('click',function(){
					jQuery('.theme-portfolio-section-wrap .project-filter-navv ul#projects-filter-menu-new li').removeClass('active');
					jQuery(this).addClass('active');
					var selector = jQuery(this).attr('data-filter');
					jQuery('.theme-portfolio-section-wrap .project-filter-itemlist-<?php echo esc_attr($dynamic_num) ?>').isotope({
						filter:selector,
					});
				});

			});
			jQuery(window).on('load',function($) {
				'use strict';
				jQuery(".theme-portfolio-section-wrap .project-filter-itemlist-<?php echo esc_attr($dynamic_num) ?>").isotope();
			});
		</script>
		
		<?php
        ob_start();
        ?>
		
		
		<div class="projects_filter_nav__Wrapper theme-portfolio-section-wrap">


            <?php if($settings['portfolio_title_style'] == 'one') : ?>

            <?php $theme_portfolio_menus = get_terms( 'theme_portfolio_cat' ); 


			if( $settings['theme_portfolio_filter_show'] == 'yes' && !empty($theme_portfolio_menus) && ! is_wp_error( $theme_portfolio_menus ) ) : ?>
            <div class="project-filter-navv theme-portfolio-filter-wrap project-nav inner-project-nav">
                <ul id="projects-filter-menu-new" class="projects_filter_nav__menu list-wrap">
                    <li class="active" data-filter="*"><?php esc_html_e('All','kewi-extra'); ?></li>
                    <?php foreach($theme_portfolio_menus as $theme_portfolio_menu){
                        echo '<li data-filter=".'.esc_attr($theme_portfolio_menu->slug).'">'.esc_html($theme_portfolio_menu->name).'</li>';
                    }?>
                </ul>
            </div>
            <?php endif; ?>

            <?php else : ?>

            <div class="row align-items-end custom-portfolio-title">

                <div class="col-lg-6">
                    <div class="section-title">
                        <span class="sub-title">Portfolio</span>
                        <h2 class="title">What we made yet</h2>
                    </div>
                </div>

                <div class="col-lg-6">

                <?php 

                $theme_portfolio_menus = get_terms( 'theme_portfolio_cat' );

                if( $settings['theme_portfolio_filter_show'] == 'yes' && !empty($theme_portfolio_menus) && ! is_wp_error( $theme_portfolio_menus ) ) : ?>
                <div class="project-filter-navv theme-portfolio-filter-wrap project-nav inner-project-nav">
                    <ul id="projects-filter-menu-new" class="projects_filter_nav__menu list-wrap">
                        <li class="active" data-filter="*"><?php esc_html_e('All','kewi-extra'); ?></li>
                        <?php foreach($theme_portfolio_menus as $theme_portfolio_menu){
                            echo '<li data-filter=".'.esc_attr($theme_portfolio_menu->slug).'">'.esc_html($theme_portfolio_menu->name).'</li>';
                        }?>
                    </ul>
                </div>
                <?php endif; ?>

                </div>

            </div>

            <?php endif; ?>


			
            <div class="theme-portfolio-grid-wrapper inner-project-wrap projects_filter_grid__Items">
                <div class="row theme-portfolio-grid project-filter-itemlist-<?php echo esc_attr($dynamic_num); ?>">
				
                    <?php global $post;
					
						$paged = get_query_var('paged') ? get_query_var('paged') : 1;
						
						$p = new \WP_Query(array(
							'posts_per_page' => esc_attr($settings['theme_portfolio_item_numbers']),
							'post_type' => 'theme_portfolio',
							'paged' => $paged
						));
					
					while($p->have_posts()) : $p->the_post();
					
					$portfolio_catagory = get_the_terms( get_the_ID(), 'theme_portfolio_cat' );
					
					if ( $portfolio_catagory && ! is_wp_error( $portfolio_catagory ) ) {
						$portfolio_cat_list = array();
						foreach ( $portfolio_catagory as $portfolio_cat ) {
							$portfolio_cat_list[] = $portfolio_cat->slug;
						}
						$portfolio_catshow = join( " ", $portfolio_cat_list );
						
					}else{
						$portfolio_catshow = '';
					}?>
					

                    <?php if($settings['theme_portfolio_style'] == 'one') : ?>

                    <div class="col-md-6 grid-item grid-sizer <?php echo esc_attr($portfolio_catshow); ?>">

                        <div class="project-item-four">
                            <div class="project-thumb-four">

                                <a href="<?php the_permalink(); ?>"><img src="<?php echo esc_attr(esc_url(get_the_post_thumbnail_url(null, 'full'))); ?>" alt="<?php the_title_attribute(); ?>"></a>

                            </div>
                            <div class="project-content-four">
                                <span>
                                    
                                    <?php  

                                        $portfolio_catagorys = get_the_terms( get_the_ID(), 'theme_portfolio_cat' ); 
                                        if ( $portfolio_catagorys && ! is_wp_error( $portfolio_catagorys ) ){
                                            foreach($portfolio_catagorys as $portfolio_catagory ){
                                            echo '<a href="'.esc_url(get_term_link($portfolio_catagory->slug, 'theme_portfolio_cat')).'">'.esc_html($portfolio_catagory->name).'</a>';
                                            }
                                        } 

                                    ?>

                                </span>

                                <h2 class="title"><a href="<?php the_permalink(); ?>" class="underline-effect"><?php echo esc_html(get_the_title()); ?></a></h2>

                            </div>
                        </div>

                    </div>

                    <?php elseif($settings['theme_portfolio_style'] == 'two') : ?>


                    <div class="col-lg-4 col-md-6 grid-item grid-sizer <?php echo esc_attr($portfolio_catshow); ?>">
                        <div class="project-item-five">
                            <div class="project-thumb-five">
                                <a href="<?php the_permalink(); ?>"><img src="<?php echo esc_attr(esc_url(get_the_post_thumbnail_url(null, 'full'))); ?>" alt="<?php the_title_attribute(); ?>"></a>
                            </div>
                        </div>
                    </div>

                    <?php elseif($settings['theme_portfolio_style'] == 'three') : ?>


                    <div class="col-lg-3 col-sm-6 grid-item grid-sizer <?php echo esc_attr($portfolio_catshow); ?>">
                        <div class="project-item-six">
                            <div class="project-thumb-six">
                                <a href="<?php the_permalink(); ?>"><img src="<?php echo esc_attr(esc_url(get_the_post_thumbnail_url(null, 'full'))); ?>" alt="<?php the_title_attribute(); ?>"></a>
                            </div>
                            <div class="project-content-six">
                                <span>
                                    
                                    <?php  

                                        $portfolio_catagorys = get_the_terms( get_the_ID(), 'theme_portfolio_cat' ); 
                                        if ( $portfolio_catagorys && ! is_wp_error( $portfolio_catagorys ) ){
                                            foreach($portfolio_catagorys as $portfolio_catagory ){
                                            echo '<a href="'.esc_url(get_term_link($portfolio_catagory->slug, 'theme_portfolio_cat')).'">'.esc_html($portfolio_catagory->name).'</a>';
                                            }
                                        } 

                                    ?>

                                </span>
                                <h2 class="title"><a href="<?php the_permalink(); ?>" class="underline-effect"><?php echo esc_html(get_the_title()); ?></a></h2>
                            </div>
                        </div>
                    </div>

                    <?php else : ?>

                    <div class="col-lg-4 col-sm-6 grid-item grid-sizer portfolio_catshow">
                        <div class="project-item-five">
                            <div class="project-thumb-five">
                                <a href="<?php the_permalink(); ?>"><img src="<?php echo esc_attr(esc_url(get_the_post_thumbnail_url(null, 'full'))); ?>" alt="<?php the_title_attribute(); ?>"></a>
                            </div>
                        </div>
                    </div>

					<?php endif; ?>


                    <?php endwhile; wp_reset_postdata(); wp_reset_query();?>
					
                </div>

                
				
                <?php if($settings['theme_portfolio_navigation_show'] == 'yes' ) { ?>
                <div class="theme-portfolo-nav">
                    <?php kewi_paginate_nav($p); ?>
                </div>
                <?php } ?>
				
            </div>
        </div>


	

	<?php echo ob_get_clean();


	}
				

}

