<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_slider_project extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'project-grid';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Project Slider', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {
		
		$this->layout_options();		
		$this->post_query_options();	
	}

	
	/**
    * Layout Options
    */
    private function layout_options() {
	
	
		$this->start_controls_section(
            'layout_option',
            [
                'label' => __( 'Layout Options', 'kewi-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		$this->add_control( 'subtitle', [
            'label'       => __( 'Sub Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'default'     => __( 'About Us', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section subtitle here.", 'kewi-extra' ),
        ] );

        $this->add_control( 'title', [
            'label'       => __( 'Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'kewi-extra' ),

        ] );

		
		$this->end_controls_section();
	
	}
	
	/**
    * Post Query Options
    */
    private function post_query_options() {
	
	
		$this->start_controls_section(
            'post_query_option',
            [
                'label' => __( 'Post Options', 'kewi-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		
		// Post Sort
		
        $this->add_control(
            'post_sorting',
            [
                'type'    => \Elementor\Controls_Manager::SELECT2,
                'label' => esc_html__('Post Sorting', 'kewi-extra'),
                'default' => 'date',
                'options' => [
					'date' => esc_html__('Recent Post', 'kewi-extra'),
                    'rand' => esc_html__('Random Post', 'kewi-extra'),
					'title'         => __( 'Title Sorting Post', 'kewi-extra' ),
                    'modified' => esc_html__('Last Modified Post', 'kewi-extra'),
                    'comment_count' => esc_html__('Most Commented Post', 'kewi-extra'),
					
                ],
            ]
        );		
		
		// Post Order
		
        $this->add_control(
            'post_ordering',
            [
                'type'    => \Elementor\Controls_Manager::SELECT2,
                'label' => esc_html__('Post Ordering', 'kewi-extra'),
                'default' => 'DESC',
                'options' => [
					'DESC' => esc_html__('Desecending', 'kewi-extra'),
                    'ASC' => esc_html__('Ascending', 'kewi-extra'),
                ],
            ]
        );
		
		
	
		
		// Post Items.
		
        $this->add_control(
            'post_number',
			[
				'label'         => esc_html__( 'Number Of Posts', 'kewi-extra' ),
				'type'          => \Elementor\Controls_Manager::NUMBER,
				'default'       => '1',
			]
        );
		
		$this->add_control(
            'enable_offset_post',
            [
               'label' => esc_html__('Enable Skip Post', 'kewi-extra'),
               'type' => \Elementor\Controls_Manager::SWITCHER,
               'label_on' => esc_html__('Yes', 'kewi-extra'),
               'label_off' => esc_html__('No', 'kewi-extra'),
               'default' => 'no',
               
            ]
        );
      
        $this->add_control(
			'post_offset_count',
			  [
			   'label'         => esc_html__( 'Skip Post Count', 'kewi-extra' ),
			   'type'          => \Elementor\Controls_Manager::NUMBER,
			   'default'       => '1',
			   'condition' => [ 'enable_offset_post' => 'yes' ]

			  ]
        );
		
		
		$this->end_controls_section();
	
	}	
	



	protected function render() {
		
		
		$settings = $this->get_settings_for_display();
		
		$post_count = $settings['post_number'];
		$post_order  = $settings['post_ordering'];
		$post_sortby = $settings['post_sorting']; 

		
		
		$args = [
            'post_type' => 'theme_portfolio',
            'post_status' => 'publish',
			'order' => $settings['post_ordering'],
			'posts_per_page' => $settings['post_number'],
			//'ignore_sticky_posts' => 1,
        ];
		
		
		// Post Sorting
        if ( ! empty( $settings['post_sorting'] ) ) {
            $args['orderby'] = $settings['post_sorting'];
        }	





		// Query
        $query = new \WP_Query( $args ); ?>
		

            <!-- project-area -->
            <section class="project-area-two">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="section-title mb-80">
                                <span class="sub-title"><?php echo $settings['subtitle']; ?></span>
                                <h2 class="title"><?php echo wp_kses_post( $settings['title'] ); ?></h2>
                            </div>
                        </div>
                    </div>

                    <?php if ( $query->have_posts() ) : ?>

                    <div class="project-item-wrap">

                        <div class="swiper-container project-active-two">

                            <div class="swiper-wrapper">


                            	<?php while ($query->have_posts()) : $query->the_post(); ?>

                                <div class="swiper-slide">
                                    <div class="project-item-two">
                                        <div class="project-thumb-two">

                                        	<a href="<?php the_permalink(); ?>"><img src="<?php echo esc_attr(esc_url(get_the_post_thumbnail_url(null, 'full'))); ?>" alt="<?php the_title_attribute(); ?>">
                                        	</a>
                                            
                                        </div>
                                        <div class="project-content-two">

                                            <span>featured</span>
                                            <h2 class="title"><a href="<?php the_permalink(); ?>" class="underline-effect"><?php echo esc_html(get_the_title()); ?></a></h2>

                                            <p>Our Sustainable Construction Advisors provide sustainable construction expertise to our building, civil & industrial project teams the SCAs work collaboratively.</p>


                                            <ul class="list-wrap">
                                                <li><span>Duration</span>

				                                <?php 
													$property_meta = get_post_meta( get_the_ID(), 'theme_portfolio_options', true );
													echo $property_meta['property_duration'];
												?>


                                                </li>
                                                <li><span>Price</span>

			                                     <?php 
												$property_meta = get_post_meta( get_the_ID(), 'theme_portfolio_options', true );
												echo $property_meta['property_price'];
												?>          


                                            </li>
                                                <li><span>Designer</span>

													<?php 
													$property_meta = get_post_meta( get_the_ID(), 'theme_portfolio_options', true );
													echo $property_meta['property_designer'];
													?>


                                                </li>
                                            </ul>

                                        </div>
                                    </div>
                                </div>

                                <?php endwhile; ?>



                            </div>


                        </div>

                       

                        <div class="swiper-scrollbar"></div>
                    </div>

                    <?php wp_reset_postdata(); ?>
		
					<?php endif; ?>


                </div>
            </section>
            <!-- project-area-end -->

		
	
		<?php 
      }
		
  		
	
}

