<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_accordion_section extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'custom-accordion-wid';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Accordion V.1', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {

		$this->start_controls_section( 'section_content_title_faq', [
            'label' => esc_html__( 'Faqs Section Title and Button', 'kewi-extra' ),
        ] );

        $this->add_control( 'title', [
            'label'       => __( 'Title', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'FAQ', 'kewi-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'kewi-extra' ),

        ] );


        $this->add_control( 'btn_text', [
            'label'       => __( 'Button Label', 'knor-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type your button label here', 'knor-extra' ),
            'default'     => __( 'Get In Touch', 'knor-extra' ),
        ] );

        $this->add_control( 'btn_link', [
            'label'       => __( 'Button Link', 'knor-extra' ),
            'type'        => \Elementor\Controls_Manager::URL,
            'placeholder' => __( 'https://your-link.com', 'knor-extra' ),
            'default'     => [
                'url' => '#',
            ],
        ] );


        $this->end_controls_section();


		$this->start_controls_section( 'section_content', [
			'label' => __( 'Faq Items Content', 'Kewi-extra' ),
		] );


		$this->add_control( 'theme-ctm-accordion', [
			'label'       => esc_html__( 'Accordion List', 'gazania-extra' ),
			'type'        => \Elementor\Controls_Manager::REPEATER,

			'fields'      => [

				[
					'name'        => 'accordion_title',
					'label'       => __( 'Title', 'Kewi-extra' ),
					'type'        => \Elementor\Controls_Manager::TEXT,
					'default'     => __( 'Give Accordion Title', 'Kewi-extra' ),
					'label_block' => true,
				],
	
				[
					'name'        => 'accordion_content',
					'label'      => __( 'Content', 'Kewi-extra' ),
					'type'       => \Elementor\Controls_Manager::WYSIWYG,
					'default'    => __( 'Give Accordion Content', 'Kewi-extra' ),
					'show_label' => false,
				],
				
				[
					'name'  => 'show_icon',
					'label' => __( 'Show Icon in Item', 'Kewi-extra' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'textdomain' ),
					'label_off' => esc_html__( 'Hide', 'textdomain' ),
					'return_value' => 'yes',
					'default' => 'no',
				],

				[
					'name'  => 'accordion_icon',
					'label'     => __( 'Icon', 'Kewi-extra' ),
					'type'      => \Elementor\Controls_Manager::ICONS,
					'default'   => [
						'value'   => 'fas fa-star',
						'library' => 'solid',
					],
					'condition' => ['show_icon' => 'yes']
				],

			],

			'default'     => [
				[
					'accordion_title'   => __( 'How this kewi works?', 'Kewi-extra' ),
					'accordion_content' => __( 'Management the nation or Saaspark is a powerful app for you to manage, create, or visualize your product and growth throughout the easiest and smoothest way possible. By giving you a simple yet amazing experience with our app.', 'Kewi-extra' ),
				],
				[
					'accordion_title'   => __( 'Are there any additional fees?', 'Kewi-extra' ),
					'accordion_content' => __( 'Management the nation or Saaspark is a powerful app for you to manage, create, or visualize your product and growth throughout the easiest and smoothest way possible. By giving you a simple yet amazing experience with our app.', 'Kewi-extra' ),
				],
				[
					'accordion_title'   => __( 'How can I get App?', 'Kewi-extra' ),
					'accordion_content' => __( 'Management the nation or Saaspark is a powerful app for you to manage, create, or visualize your product and growth throughout the easiest and smoothest way possible. By giving you a simple yet amazing experience with our app.', 'Kewi-extra' ),
				],
				[
					'accordion_title'   => __( 'What features do Saaspark have and other not?', 'Kewi-extra' ),
					'accordion_content' => __( 'Management the nation or Saaspark is a powerful app for you to manage, create, or visualize your product and growth throughout the easiest and smoothest way possible. By giving you a simple yet amazing experience with our app.', 'Kewi-extra' ),
				],

			],

			'title_field' => '{{{ accordion_title }}}',


		] );


		$this->end_controls_section();






		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

		$accordion = $settings['theme-ctm-accordion'];


		
		$faq_id = 'theme-accordion-' . substr( $this->get_id_int(), 0, 3 );
		$faq    = 'theme-acc-' . substr( $this->get_id_int(), 0, 3 );
		$faq_o  = 'theme-acco-' . substr( $this->get_id_int(), 0, 3 );
		?>

		<div class="faq-content">
            <div class="section-title">
                <span class="sub-title"><?php echo $settings['title']; ?></span>
            </div>

		<div class="accordion-wrap theme-accordion-wrapper theme-custom-accordion" id="<?php echo esc_attr( $faq_id ); ?>">

			<?php foreach ( $accordion as $index => $item ) :
				$tab_btn_setting_key = $this->get_repeater_setting_key( 'accordion_title', '', $index );

				$this->add_render_attribute( $tab_btn_setting_key, [
					'class'          => [ $index == 0 ? 'accordion-button' : 'accordion-button collapsed' ],
					'data-bs-toggle' => 'collapse',
					'data-bs-target' => '#' . 'faq-collapse-' . $faq_o . '-' . $index,
					'aria-expanded'  => $index == 0 ? 'true' : 'false',
					'type'           => 'button',
					'aria-controls'  => $faq_o . '-' . $index
				] );

				$tab_body_setting_key = $this->get_repeater_setting_key( 'accordion_content', '', $index );

				$this->add_render_attribute( $tab_body_setting_key, [
					'id'             => 'faq-collapse-' . $faq_o . '-' . $index,
					'class'          => [ $index == 0 ? 'accordion-collapse collapse show' : 'accordion-collapse collapse' ],
					'data-bs-parent' => "#" . $faq_id
				] );
				?>

				<div class="accordion-item <?php echo $index == 0 ? 'active' : ''; ?>">

					<h2 class="accordion-header" id="<?php echo $faq_o . '-' . $index; ?>">
						<button <?php echo $this->get_render_attribute_string( $tab_btn_setting_key ); ?>>

							<?php if ( $item['show_icon'] === 'yes' && !empty( $item['accordion_icon'] ) ) : ?>
								<div class="accordion-icon-wrap">
									<?php \Elementor\Icons_Manager::render_icon( $item['accordion_icon'], [ 'aria-hidden' => 'true' ] ); ?>
								</div>
							<?php endif; ?>

							<?php echo $item['accordion_title']; ?>
						</button>
					</h2>

					<div <?php echo $this->get_render_attribute_string( $tab_body_setting_key ); ?>>
						<div class="accordion-body-wrap">
							<?php echo $item['accordion_content']; ?>
						</div>
					</div>

				</div>

			<?php endforeach; ?>


		</div>

		<div class="touch-btn mt-50">
            <a href="<?php echo esc_url( $settings['btn_link']['url'] ) ?>" class="btn"><span><?php echo $settings['btn_text']; ?></span></a>
        </div>

		</div>

		<?php



	}
				

}

