<?php

/**
 * Elementor Widget
 * @package Kewi
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_video_box_two extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'custom-video-box-wid-two';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Video Box V.2', 'kewi-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kewi_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


		$this->start_controls_section(
            'video_box_options',
            [
                'label' => esc_html__( 'Video Box Content', 'restlycore' ),
                'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'video_box_img',
            [
                'label' => esc_html__('Video Wrapper Image','restlycore'),
                'type'=> \Elementor\Controls_Manager::MEDIA,
                'default' => [
                  'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'label_block' => true,
            ]
        );

        $this->add_responsive_control(
            'box_img_height',
            [
                'label' =>esc_html__( 'Set Box Image Height', 'kewi-extra' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 750,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 400,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 400,
                    'unit' => 'px',
                ],
                
                'default'  => [
                    'unit' => 'px',
                    'size' => 750,
                ],
                
                'selectors' => [
                    '{{WRAPPER}} .theme-video-wrap .video-img' => 'min-height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );      
        

        $this->add_control(
            'video_link', [
                'label' => __( 'Insert Self Hosted Video URL Link in Video format(eg. mp4/flv etc).', 'gazania-extra' ),
                'type'        => \Elementor\Controls_Manager::URL,

                'default'     => [
                    'url' => 'https://www.youtube.com/watch?v=9Oia-ki4iyw',
                ],
                
                'description' => esc_html__( 'Enter Video URL', 'gazania-extra' )
            ]
        );


        $this->end_controls_section();

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

		
		?>

            <!-- parallax-video-area -->
            <div class="parallax-video theme-video-wrap-two" data-background="<?php echo esc_url( $settings['video_box_img']['url'] ); ?>" data-jarallax
                data-video-src="<?php echo esc_url( $settings['video_link']['url'] ) ?>" style="background-image: url(<?php echo esc_url( $settings['video_box_img']['url'] ); ?>);"></div>
            <!-- parallax-video-area-end -->

	

	<?php 


	}
				

}

